##  Deleting S-User IDs
### Procedure
  1. Go to SAP for Me.
  2. In the User Management area, go to Home > Users & Contacts > User Management.
  3. Select the user that you want to delete.
  4. Choose Delete.
